diff -ur nano-2.2.0/UPGRADE nano-2.2.0-fixed/UPGRADE
--- nano-2.2.0/UPGRADE	2009-08-13 22:16:33.000000000 -0500
+++ nano-2.2.0-fixed/UPGRADE	2009-11-30 12:39:51.832677749 -0600
@@ -1,6 +1,22 @@
 GNU nano upgrading information
 ==============================
 
+Visible changes since 2.0
+-------------------------
+* Editor Features
+  - The ability to rebind (reassign) keys using the nanorc.
+  - The ability to read standard input like a pager ("nano -").
+  - Color syntax highlighting can be set by the first line of a file.
+  - The ability to silence nanorc error messages (-q).
+  - Undo/redo operations (-u).
+  - Soft wrapping of text (-$).
+
+* File Handling
+  - Better handling of backup files: if nano can't write a backup file,
+    it won't try to write the original file afterward.
+  - Emergency savefiles retain ownerships and permissions when possible.
+  - Performance improvements in color syntax highlighting.
+
 Visible changes since 1.2
 -------------------------
 * Editor Features
diff -ur nano-2.2.0/doc/faq.html nano-2.2.0-fixed/doc/faq.html
--- nano-2.2.0/doc/faq.html	2009-11-18 16:09:37.000000000 -0600
+++ nano-2.2.0-fixed/doc/faq.html	2009-11-30 12:08:23.785006048 -0600
@@ -83,9 +83,9 @@
 <h2><a name="1.5"></a>1.5. Why the name change from TIP?</h2>
 <blockquote><p>On January 10, 2000, TIP was officially renamed to nano because of a namespace conflict with another program called 'tip'. The original 'tip' program &quot;establishes a full duplex terminal connection to a remote host&quot;, and was included with many older Unix systems (and newer ones like Solaris). The conflict was not noticed at first because there is no 'tip' utility included with most GNU/Linux distributions (where nano was developed).</p></blockquote>
 <h2><a name="1.6"></a>1.6. What is the current version of nano?</h2>
-<blockquote><p>The current version of nano *should* be 2.0.7. Of course, you should always check the nano homepage to see what the latest and greatest version is.</p></blockquote>
+<blockquote><p>The current version of nano *should* be 2.2.0. Of course, you should always check the nano homepage to see what the latest and greatest version is.</p></blockquote>
 <h2><a name="1.7"></a>1.7. I want to read the man page without having to download the program!</h2>
-<blockquote><p>Jeez, demanding, aren't we? Okay, look <a href="http://www.nano-editor.org/dist/v2.0/nano.1.html">here</a>.</p></blockquote>
+<blockquote><p>Jeez, demanding, aren't we? Okay, look <a href="http://www.nano-editor.org/dist/v2.2/nano.1.html">here</a>.</p></blockquote>
 <hr width="100%">
 <h1><a name="2"></a>2. Where to get GNU nano.</h1>
 <h2><a name="2.1"></a>2.1. FTP and WWW sites that carry nano.</h2>
@@ -99,8 +99,8 @@
 <h2><a name="2.2"></a>2.2. RedHat and derivatives (.rpm) packages.</h2>
 <blockquote>
   <ul>
-    <li><a href="http://www.nano-editor.org/dist/v2.0/RPMS/">http://www.nano-editor.org/dist/v2.0/RPMS/</a></li>
-    <li><a href="http://www.ewtoo.org/~astyanax/nano/dist/v2.0/RPMS/">http://www.ewtoo.org/~astyanax/nano/dist/v2.0/RPMS/</a></li>
+    <li><a href="http://www.nano-editor.org/dist/v2.2/RPMS/">http://www.nano-editor.org/dist/v2.2/RPMS/</a></li>
+    <li><a href="http://www.ewtoo.org/~astyanax/nano/dist/v2.2/RPMS/">http://www.ewtoo.org/~astyanax/nano/dist/v2.2/RPMS/</a></li>
   </ul>
 </blockquote>
 <h2><a name="2.3"></a>2.3. Debian (.deb) packages.</h2>
@@ -246,7 +246,7 @@
   help-nano - <a href="http://mail.gnu.org/mailman/listinfo/help-nano/">http://mail.gnu.org/mailman/listinfo/help-nano/</a><br>
   nano-devel - <a href="http://mail.gnu.org/mailman/listinfo/nano-devel/">http://mail.gnu.org/mailman/listinfo/nano-devel/</a></p></blockquote>
 <h2><a name="7.2"></a>7.2. I want to send the development team a big load of cash (or just a thank you).</h2>
-<blockquote><p>That's fine. Send it <a href="mailto:nano-devel@gnu.org">our way</a>! Better yet, fix a <a href="http://www.nano-editor.org/dist/v2.0/BUGS">bug</a> in the program or implement a <a href="http://www.nano-editor.org/dist/v2.0/TODO">cool feature</a> and send us that instead (though cash is fine too).</p></blockquote>
+<blockquote><p>That's fine. Send it <a href="mailto:nano-devel@gnu.org">our way</a>! Better yet, fix a <a href="http://www.nano-editor.org/dist/v2.2/BUGS">bug</a> in the program or implement a <a href="http://www.nano-editor.org/dist/v2.2/TODO">cool feature</a> and send us that instead (though cash is fine too).</p></blockquote>
 <h2><a name="7.3"></a>7.3. How do I submit a bug report or patch?</h2>
 <blockquote>
 <p>The best place to submit bugs is to the <A HREF="https://savannah.gnu.org/bugs/?group=nano">Savannah bug tracker</A> as you can check whether the bug you are submitting has already been submitted.
@@ -256,8 +256,10 @@
 <h2><a name="7.5"></a>7.5. Can I have write access to the subversion tree?</h2>
 <blockquote><p>Re-read Section <a href="#7.4">7.4</a> and you should know the answer.</p></blockquote>
 <h2><a name="8"></a>8. ChangeLog</h2>
-<blockquote><p>2007/12/21 - Update maintainer information. (DLR)<br>
-2008/03/16 - Update docs to refer to subversion instead of CVS, add more words about Apline, and refer to Savannah for bugs and patches.  (chrisa)
+<blockquote><p>2009/11/30 - Update various bits for nano 2.2.x. (DLR)<br>
+2009/11/18 - Typo fix. (j.mader@gmail.com)<br>
+2008/03/16 - Update docs to refer to subversion instead of CVS, add more words about Alpine, and refer to Savannah for bugs and patches. (chrisa)<br>
+2007/12/21 - Update maintainer information. (DLR)<br>
 2007/12/09 - Add minor punctuation and wording fixes, and update various sections to account for Alpine. (DLR)<br>
 2007/08/26 - Update links to the Free Translation Project. (DLR)<br>
 2007/07/29 - Update RPM links for nano 2.0.x. (DLR)<br>
diff -ur nano-2.2.0/doc/man/nano.1 nano-2.2.0-fixed/doc/man/nano.1
--- nano-2.2.0/doc/man/nano.1	2009-11-26 20:49:31.000000000 -0600
+++ nano-2.2.0-fixed/doc/man/nano.1	2009-11-30 13:03:19.860347006 -0600
@@ -1,6 +1,6 @@
 .\" Hey, EMACS: -*- nroff -*-
-.\" Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
-.\" Free Software Foundation, Inc.
+.\" Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,
+.\" 2008, 2009 Free Software Foundation, Inc.
 .\"
 .\" This document is dual-licensed.  You may distribute and/or modify it
 .\" under the terms of either of the following licenses:
@@ -19,7 +19,7 @@
 .\"   <http://www.gnu.org/licenses/>.
 .\"
 .\" $Id: nano.1 4443 2009-11-27 02:50:12Z astyanax $
-.TH NANO 1 "version 2.0.0" "August 23, 2007"
+.TH NANO 1 "version 2.2.0" "November 30, 2009"
 .\" Please adjust this date whenever revising the manpage.
 .\"
 
@@ -79,11 +79,11 @@
 .TP
 .B \-H (\-\-historylog)
 Log search and replace strings to \fI~/.nano_history\fP, so they can be
-retrieved in later sessions, if nanorc support is available.
+retrieved in later sessions, if \fInanorc\fP support is available.
 .TP
 .B \-I (\-\-ignorercfiles)
-Don't look at \fISYSCONFDIR/nanorc\fP or \fI~/.nanorc\fP, if nanorc
-support is available.
+Don't look at \fISYSCONFDIR/nanorc\fP or \fI~/.nanorc\fP, if
+\fInanorc\fP support is available.
 .TP
 .B \-K (\-\-rebindkeypad)
 Interpret the numeric keypad keys so that they all work properly.  You
@@ -107,10 +107,11 @@
 .TP
 .B \-R (\-\-restricted)
 Restricted mode: don't read or write to any file not specified on the
-command line; read any nanorc files; allow suspending; allow a file
-to be appended to, prepended to, or saved under a different name if it
-already has one; or use backup files or spell checking.  Also accessible
-by invoking \fBnano\fP with any name beginning with 'r' (e.g. "rnano").
+command line; read any \fInanorc\fP files; allow suspending; allow a
+file to be appended to, prepended to, or saved under a different name if
+it already has one; or use backup files or spell checking.  Also
+accessible by invoking \fBnano\fP with any name beginning with 'r' (e.g.
+"rnano").
 .TP
 .B \-S (\-\-smooth)
 Enable smooth scrolling.  Text will scroll line-by-line, instead of the
@@ -173,8 +174,8 @@
 by the terminal.
 .TP
 .B \-q (\-\-quiet)
-Do not report errors in the nanorc file and ask them to
-be acknowledged by pressing enter at startup.
+Do not report errors in the \fInanorc\fP file and ask them to be
+acknowledged by pressing Enter at startup.
 .TP
 .B \-r \fIcols\fP (\-\-fill=\fIcols\fP)
 Wrap lines at column \fIcols\fP.  If this value is 0 or less, wrapping
@@ -206,11 +207,11 @@
 Enable suspend ability.
 .TP
 .B \-$ (\-\-softwrap)
-Enable 'soft wrapping'.  Nano will attempt to display lines the entire 
-contents of a line, even if it is longer than the screen width.
-Since '$' normally refers to a variable in the Unix shell, you should
-specify this option last when using other options (e.g. 'nano -wS$') 
-or pass it separately (e.g. 'nano -wS -$'). 
+Enable 'soft wrapping'.  \fBnano\fP will attempt to display the entire
+contents of a line, even if it is longer than the screen width.  Since
+'$' normally refers to a variable in the Unix shell, you should specify
+this option last when using other options (e.g. 'nano -wS$') or pass it
+separately (e.g. 'nano -wS -$').
 .TP
 .B \-a, \-b, \-e, \-f, \-g, \-j
 Ignored, for compatibility with Pico.
@@ -223,7 +224,7 @@
 
 .SH NOTES
 If no alternative spell checker command is specified on the command
-line or in one of the nanorc files, \fBnano\fP will check the
+line or in one of the \fInanorc\fP files, \fBnano\fP will check the
 \fBSPELL\fP environment variable for one.
 
 In some cases \fBnano\fP will try to dump the buffer into an emergency
diff -ur nano-2.2.0/doc/man/nanorc.5 nano-2.2.0-fixed/doc/man/nanorc.5
--- nano-2.2.0/doc/man/nanorc.5	2009-11-26 20:49:31.000000000 -0600
+++ nano-2.2.0-fixed/doc/man/nanorc.5	2009-11-30 12:57:05.996445934 -0600
@@ -1,5 +1,5 @@
 .\" Hey, EMACS: -*- nroff -*-
-.\" Copyright (C) 2003, 2004, 2005, 2006, 2007
+.\" Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009
 .\" Free Software Foundation, Inc.
 .\"
 .\" This document is dual-licensed.  You may distribute and/or modify it
@@ -19,7 +19,7 @@
 .\"   <http://www.gnu.org/licenses/>.
 .\"
 .\" $Id: nanorc.5 4443 2009-11-27 02:50:12Z astyanax $
-.TH NANORC 5 "version 2.0.0" "August 23, 2007"
+.TH NANORC 5 "version 2.2.0" "November 30, 2009"
 .\" Please adjust this date whenever revising the manpage.
 .\"
 .SH NAME
@@ -45,9 +45,9 @@
 and \fBicolor\fP keywords are used to define syntax highlighting rules
 for different text patterns.  \fBnano\fP will read one command per line.
 
-Options in nanorc files take precedence over nano's defaults, and
-command line options override nanorc settings.  Also, options are unset
-by default, except for those that take arguments.
+Options in \fInanorc\fP files take precedence over nano's defaults, and
+command line options override \fInanorc\fP settings.  Also, options are
+unset by default, except for those that take arguments.
 
 Quotes inside string parameters don't have to be escaped with
 backslashes.  The last double quote in the string will be treated as its
@@ -146,9 +146,9 @@
 The default value is "\fI!.?\fP".
 .TP
 .B set/unset quiet
-\fBnano\fP will not report errors in the nanorc file and ask them to 
-be acknowledged by pressing enter at startup.  If this is used it should
-be placed at the top of the file to be fully effective.
+\fBnano\fP will not report errors in the \fInanorc\fP file and ask them
+to be acknowledged by pressing enter at startup.  If this is used it
+should be placed at the top of the file to be fully effective.
 .TP
 .B set/unset quickblank
 Do quick statusbar blanking.  Statusbar messages will disappear after 1
@@ -414,7 +414,7 @@
 Undo the text action peformed (add text, delete text, etc).
 .TP
 .B redo
-"Re-do" the last undone action (i.e. undo an undo)
+Redo the last undone action (i.e., undo an undo).
 .TP
 .B suspend
 Suspend the editor (if the suspend function is enabled, see the 
diff -ur nano-2.2.0/doc/nanorc.sample.in nano-2.2.0-fixed/doc/nanorc.sample.in
--- nano-2.2.0/doc/nanorc.sample.in	2009-11-27 22:00:04.000000000 -0600
+++ nano-2.2.0-fixed/doc/nanorc.sample.in	2009-11-30 13:10:24.816567063 -0600
@@ -141,6 +141,9 @@
 ## Use smooth scrolling as the default.
 # set smooth
 
+## Enable soft line wrapping (AKA full line display).
+# set softwrap
+
 ## Use this spelling checker instead of the internal one.  This option
 ## does not properly have a default value.
 ##
@@ -149,6 +152,10 @@
 ## Allow nano to be suspended.
 # set suspend
 
+## If nano is allowed to be suspended, allow the suspend key (usually
+## ^Z) to actually suspend it.
+# set suspendenable
+
 ## Use this tab size instead of the default; it must be greater than 0.
 # set tabsize 8
 
@@ -158,6 +165,10 @@
 ## Save automatically on exit, don't prompt.
 # set tempfile
 
+## Enable the new (EXPERIMENTAL) generic undo code, not just for line
+## cuts.
+# set undo
+
 ## Disallow file modification.  Why would you want this in an rcfile? ;)
 # set view
 
@@ -170,12 +181,6 @@
 ## characters as parts of words.
 # set wordbounds
 
-## Enable the new (EXPERIMENTAL) generic undo code, not just for line cuts
-# set undo
-
-## Enable soft line wrapping (AKA full line display)
-# set softwrap
-
 
 ## Color setup
 ##
diff -ur nano-2.2.0/doc/syntax/nanorc.nanorc nano-2.2.0-fixed/doc/syntax/nanorc.nanorc
--- nano-2.2.0/doc/syntax/nanorc.nanorc	2009-08-13 22:16:32.000000000 -0500
+++ nano-2.2.0-fixed/doc/syntax/nanorc.nanorc	2009-11-30 13:26:20.712218918 -0600
@@ -4,7 +4,7 @@
 ## Possible errors and parameters
 icolor brightwhite "^[[:space:]]*((un)?set|include|syntax|i?color).*$"
 ## Keywords
-icolor brightgreen "^[[:space:]]*(set|unset)[[:space:]]+(autoindent|backup|backupdir|backwards|boldtext|brackets|casesensitive|const|cut|fill|historylog|matchbrackets|morespace|mouse|multibuffer|noconvert|nofollow|nohelp|nonewlines|nowrap|operatingdir|preserve|punct)\>" "^[[:space:]]*(set|unset)[[:space:]]+(quickblank|quotestr|rebinddelete|rebindkeypad|regexp|smarthome|smooth|speller|suspend|tabsize|tabstospaces|tempfile|view|whitespace|wordbounds)\>"
+icolor brightgreen "^[[:space:]]*(set|unset)[[:space:]]+(autoindent|backup|backupdir|backwards|boldtext|brackets|casesensitive|const|cut|fill|historylog|matchbrackets|morespace|mouse|multibuffer|noconvert|nofollow|nohelp|nonewlines|nowrap|operatingdir|preserve|punct)\>" "^[[:space:]]*(set|unset)[[:space:]]+(quickblank|quotestr|rebinddelete|rebindkeypad|regexp|smarthome|smooth|softwrap|speller|suspend|suspendenable|tabsize|tabstospaces|tempfile|undo|view|whitespace|wordbounds)\>"
 icolor green "^[[:space:]]*(set|unset|include|syntax|header)\>"
 ## Colors
 icolor yellow "^[[:space:]]*i?color[[:space:]]*(bright)?(white|black|red|blue|green|yellow|magenta|cyan)?(,(white|black|red|blue|green|yellow|magenta|cyan))?\>"
diff -ur nano-2.2.0/doc/texinfo/nano.texi nano-2.2.0-fixed/doc/texinfo/nano.texi
--- nano-2.2.0/doc/texinfo/nano.texi	2009-08-13 22:16:32.000000000 -0500
+++ nano-2.2.0-fixed/doc/texinfo/nano.texi	2009-11-30 13:24:50.201995969 -0600
@@ -8,8 +8,8 @@
 @c Run 'makeinfo' rather than 'texinfo-format-buffer'.
 @smallbook
 @set EDITION 0.1
-@set VERSION 2.0.0
-@set UPDATED 17 Dec 2007
+@set VERSION 2.2.0
+@set UPDATED 30 Nov 2009
 
 @dircategory Editors
 @direntry
@@ -23,7 +23,7 @@
 @titlepage
 @title GNU @code{nano}
 @subtitle a small and friendly text editor.
-@subtitle version 2.0.0
+@subtitle version 2.2.0
 
 @author Chris Allegretta
 @page
@@ -33,8 +33,8 @@
 
 This manual is part of the GNU @code{nano} distribution.@*
 @sp4
-Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
-Free Software Foundation, Inc.
+Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,
+2008, 2009 Free Software Foundation, Inc.
 
 This document is dual-licensed.  You may distribute and/or modify it
 under the terms of either of the following licenses:
@@ -249,6 +249,10 @@
 Preserve the ^Q (XON) and ^S (XOFF) sequences so data being sent to the
 editor can be can be stopped and started.
 
+@item -q, --quiet
+Do not report errors in the nanorc file and ask them to be acknowledged
+by pressing Enter at startup.
+
 @item -r <#cols>, --fill=<#cols>
 Wrap lines at column #cols.  If this value is 0 or less, wrapping will
 occur at the width of the screen less #cols, allowing it to vary along
@@ -266,6 +270,10 @@
 exiting, assume yes.  This is most useful when using @code{nano} as the
 composer of a mailer program.
 
+@item -u, --undo
+Enable experimental generic-purpose undo code.  By default, the undo and
+redo shortcuts are Meta-U and Meta-E, respectively.
+
 @item -v, --view
 Don't allow the contents of the file to be altered.  Note that this
 option should NOT be used in place of correct file permissions to
@@ -288,6 +296,13 @@
 Enable @code{nano}'s suspend ability using the system's suspend
 keystroke (usually ^Z).
 
+@item -$, --softwrap
+Enable 'soft wrapping'.  @code{nano} will attempt to display the entire
+contents of a line, even if it is longer than the screen width.  Since
+'$' normally refers to a variable in the Unix shell, you should specify
+this option last when using other options (e.g. 'nano -wS$') or pass it
+separately (e.g. 'nano -wS -$').
+
 @item -a, -b, -e, -f, -g, -j
 Ignored, for compatibility with Pico.
 @end table
@@ -447,6 +462,9 @@
 @item Suspend Toggle (Meta-Z)
 toggles the -z (@code{--suspend}) command line option.
 
+@item Soft Wrapping Toggle (Meta-$)
+toggles the -$ (@code{--softwrap}) command line option.
+
 @end table
 
 
@@ -615,6 +633,9 @@
 @item set/unset smooth
 Use smooth scrolling by default.
 
+@item set/unset softwrap
+Use soft wrapping by default.
+
 @item set speller "spellprog"
 Use spelling checker "spellprog" instead of the built-in one, which
 calls "spell".
@@ -622,6 +643,10 @@
 @item set/unset suspend
 Allow @code{nano} to be suspended.
 
+@item set/unset suspendenable
+If @code{nano} is allowed to be suspended, allow the suspend key
+(usually ^Z) to actually suspend it.
+
 @item set tabsize "n"
 Use a tab size of "n" columns.  The value of "n" must be greater than 0.
 The default value is 8.
@@ -632,6 +657,9 @@
 @item set/unset tempfile
 Save automatically on exit, don't prompt.
 
+@item set/unset undo
+Enable experimental generic-purpose undo code.
+
 @item set/unset view
 Disallow file modification.
 
diff -ur nano-2.2.0/src/browser.c nano-2.2.0-fixed/src/browser.c
--- nano-2.2.0/src/browser.c	2009-11-14 13:37:15.000000000 -0600
+++ nano-2.2.0-fixed/src/browser.c	2009-11-30 11:56:09.351697025 -0600
@@ -2,7 +2,7 @@
 /**************************************************************************
  *   browser.c                                                            *
  *                                                                        *
- *   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007               *
+ *   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009   *
  *   Free Software Foundation, Inc.                                       *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
diff -ur nano-2.2.0/src/chars.c nano-2.2.0-fixed/src/chars.c
--- nano-2.2.0/src/chars.c	2009-11-29 00:12:39.000000000 -0600
+++ nano-2.2.0-fixed/src/chars.c	2009-11-30 11:56:25.436839976 -0600
@@ -2,7 +2,7 @@
 /**************************************************************************
  *   chars.c                                                              *
  *                                                                        *
- *   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007               *
+ *   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009   *
  *   Free Software Foundation, Inc.                                       *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
diff -ur nano-2.2.0/src/color.c nano-2.2.0-fixed/src/color.c
--- nano-2.2.0/src/color.c	2009-08-13 22:16:32.000000000 -0500
+++ nano-2.2.0-fixed/src/color.c	2009-11-30 11:56:38.755657871 -0600
@@ -2,7 +2,7 @@
 /**************************************************************************
  *   color.c                                                              *
  *                                                                        *
- *   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007               *
+ *   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009   *
  *   Free Software Foundation, Inc.                                       *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
diff -ur nano-2.2.0/src/cut.c nano-2.2.0-fixed/src/cut.c
--- nano-2.2.0/src/cut.c	2009-08-13 22:16:32.000000000 -0500
+++ nano-2.2.0-fixed/src/cut.c	2009-11-30 11:57:02.011992133 -0600
@@ -2,8 +2,8 @@
 /**************************************************************************
  *   cut.c                                                                *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
diff -ur nano-2.2.0/src/files.c nano-2.2.0-fixed/src/files.c
--- nano-2.2.0/src/files.c	2009-11-29 00:12:39.000000000 -0600
+++ nano-2.2.0-fixed/src/files.c	2009-11-30 11:57:19.581727748 -0600
@@ -2,8 +2,8 @@
 /**************************************************************************
  *   files.c                                                              *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
diff -ur nano-2.2.0/src/global.c nano-2.2.0-fixed/src/global.c
--- nano-2.2.0/src/global.c	2009-11-29 00:23:27.000000000 -0600
+++ nano-2.2.0-fixed/src/global.c	2009-11-30 11:57:35.614838108 -0600
@@ -2,8 +2,8 @@
 /**************************************************************************
  *   global.c                                                             *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
diff -ur nano-2.2.0/src/help.c nano-2.2.0-fixed/src/help.c
--- nano-2.2.0/src/help.c	2009-08-13 22:16:32.000000000 -0500
+++ nano-2.2.0-fixed/src/help.c	2009-11-30 11:57:56.752697923 -0600
@@ -2,8 +2,8 @@
 /**************************************************************************
  *   help.c                                                               *
  *                                                                        *
- *   Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007         *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,  *
+ *   2009 Free Software Foundation, Inc.                                  *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
diff -ur nano-2.2.0/src/move.c nano-2.2.0-fixed/src/move.c
--- nano-2.2.0/src/move.c	2009-11-26 21:04:18.000000000 -0600
+++ nano-2.2.0-fixed/src/move.c	2009-11-30 11:58:13.338691097 -0600
@@ -2,8 +2,8 @@
 /**************************************************************************
  *   move.c                                                               *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
diff -ur nano-2.2.0/src/nano.h nano-2.2.0-fixed/src/nano.h
--- nano-2.2.0/src/nano.h	2009-11-14 13:37:35.000000000 -0600
+++ nano-2.2.0-fixed/src/nano.h	2009-11-30 11:58:39.961208053 -0600
@@ -2,8 +2,8 @@
 /**************************************************************************
  *   nano.h                                                               *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
diff -ur nano-2.2.0/src/prompt.c nano-2.2.0-fixed/src/prompt.c
--- nano-2.2.0/src/prompt.c	2009-11-29 00:12:39.000000000 -0600
+++ nano-2.2.0-fixed/src/prompt.c	2009-11-30 11:58:58.153790296 -0600
@@ -2,8 +2,8 @@
 /**************************************************************************
  *   prompt.c                                                             *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
diff -ur nano-2.2.0/src/proto.h nano-2.2.0-fixed/src/proto.h
--- nano-2.2.0/src/proto.h	2009-11-29 00:12:39.000000000 -0600
+++ nano-2.2.0-fixed/src/proto.h	2009-11-30 11:59:14.446847489 -0600
@@ -2,8 +2,8 @@
 /**************************************************************************
  *   proto.h                                                              *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
diff -ur nano-2.2.0/src/rcfile.c nano-2.2.0-fixed/src/rcfile.c
--- nano-2.2.0/src/rcfile.c	2009-11-26 23:09:15.000000000 -0600
+++ nano-2.2.0-fixed/src/rcfile.c	2009-11-30 11:59:26.241044929 -0600
@@ -2,7 +2,7 @@
 /**************************************************************************
  *   rcfile.c                                                             *
  *                                                                        *
- *   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007               *
+ *   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009   *
  *   Free Software Foundation, Inc.                                       *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
diff -ur nano-2.2.0/src/search.c nano-2.2.0-fixed/src/search.c
--- nano-2.2.0/src/search.c	2009-08-13 22:16:32.000000000 -0500
+++ nano-2.2.0-fixed/src/search.c	2009-11-30 11:59:51.695914520 -0600
@@ -2,8 +2,8 @@
 /**************************************************************************
  *   search.c                                                             *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
diff -ur nano-2.2.0/src/text.c nano-2.2.0-fixed/src/text.c
--- nano-2.2.0/src/text.c	2009-11-29 00:12:39.000000000 -0600
+++ nano-2.2.0-fixed/src/text.c	2009-11-30 12:00:11.611137169 -0600
@@ -2,8 +2,8 @@
 /**************************************************************************
  *   text.c                                                               *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
diff -ur nano-2.2.0/src/utils.c nano-2.2.0-fixed/src/utils.c
--- nano-2.2.0/src/utils.c	2009-11-26 12:19:56.000000000 -0600
+++ nano-2.2.0-fixed/src/utils.c	2009-11-30 12:00:29.872680837 -0600
@@ -2,8 +2,8 @@
 /**************************************************************************
  *   utils.c                                                              *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
diff -ur nano-2.2.0/src/winio.c nano-2.2.0-fixed/src/winio.c
--- nano-2.2.0/src/winio.c	2009-11-29 00:12:39.000000000 -0600
+++ nano-2.2.0-fixed/src/winio.c	2009-11-30 12:00:46.160742237 -0600
@@ -2,8 +2,8 @@
 /**************************************************************************
  *   winio.c                                                              *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *

diff -ur nano-2.2.0/src/nano.c nano-2.2.0-fixed/src/nano.c
--- nano-2.2.0/src/nano.c	2009-11-29 00:23:27.000000000 -0600
+++ nano-2.2.0-fixed/src/nano.c	2009-11-30 11:58:23.455184526 -0600
@@ -2,8 +2,8 @@
 /**************************************************************************
  *   nano.c                                                               *
  *                                                                        *
  *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
  *   Free Software Foundation, Inc.                                       *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
@@ -936,8 +936,8 @@
 {
     printf(_(" GNU nano version %s (compiled %s, %s)\n"), VERSION,
 	__TIME__, __DATE__);
-    printf(" (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007\n");
-    printf(" Free Software Foundation, Inc.\n");
+    printf(" (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,\n");
+    printf(" 2008, 2009 Free Software Foundation, Inc.\n");
     printf(
 	_(" Email: nano@nano-editor.org	Web: http://www.nano-editor.org/"));
     printf(_("\n Compiled options:"));
@@ -2,8 +2,8 @@
  *   nano.c                                                               *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *